# Code of conduct

We encourage contributors and users to respect this code of conduct. 

## Respect

Please show respect, and don't blast people. 

## Politeness

Make any feedback you provide constructive rather than negative. 

## Code reviews

As a general rule in the industry, it's recommended to focus on the things to improve and how, rather than trying to blame people which can be counter-productive.
